# Changelog

All notable changes to this project will be documented in this file.

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.0.10

([Full Changelog](https://github.com/jupyter-server/synchronizer/compare/v0.0.9...61c07f22e8792b283a91c0b82f0723d8f1002a6e))

### Maintenance and upkeep improvements

- Update Release Scripts [#91](https://github.com/jupyter-server/synchronizer/pull/91) ([@blink1073](https://github.com/blink1073))
- chore: update pre-commit hooks [#90](https://github.com/jupyter-server/synchronizer/pull/90) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- chore: update pre-commit hooks [#89](https://github.com/jupyter-server/synchronizer/pull/89) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Update ruff config [#88](https://github.com/jupyter-server/synchronizer/pull/88) ([@blink1073](https://github.com/blink1073))
- chore: update pre-commit hooks [#87](https://github.com/jupyter-server/synchronizer/pull/87) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- chore: update pre-commit hooks [#86](https://github.com/jupyter-server/synchronizer/pull/86) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Update typing for traitlets 5.13 [#85](https://github.com/jupyter-server/synchronizer/pull/85) ([@blink1073](https://github.com/blink1073))
- Adopt ruff format [#84](https://github.com/jupyter-server/synchronizer/pull/84) ([@blink1073](https://github.com/blink1073))
- Update typing for traitlets 5.11 [#83](https://github.com/jupyter-server/synchronizer/pull/83) ([@blink1073](https://github.com/blink1073))
- chore: update pre-commit hooks [#82](https://github.com/jupyter-server/synchronizer/pull/82) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Adopt sp repo review [#81](https://github.com/jupyter-server/synchronizer/pull/81) ([@blink1073](https://github.com/blink1073))
- Bump actions/checkout from 3 to 4 [#79](https://github.com/jupyter-server/synchronizer/pull/79) ([@dependabot](https://github.com/dependabot))
- Use local coverage [#75](https://github.com/jupyter-server/synchronizer/pull/75) ([@blink1073](https://github.com/blink1073))
- Add more linting [#69](https://github.com/jupyter-server/synchronizer/pull/69) ([@blink1073](https://github.com/blink1073))
- Add docstring enforcement [#67](https://github.com/jupyter-server/synchronizer/pull/67) ([@blink1073](https://github.com/blink1073))
- Adopt ruff and address lint [#66](https://github.com/jupyter-server/synchronizer/pull/66) ([@blink1073](https://github.com/blink1073))
- Fix test setup [#64](https://github.com/jupyter-server/synchronizer/pull/64) ([@blink1073](https://github.com/blink1073))
- Clean up workflows and add badges [#62](https://github.com/jupyter-server/synchronizer/pull/62) ([@blink1073](https://github.com/blink1073))
- CI Cleanup [#60](https://github.com/jupyter-server/synchronizer/pull/60) ([@blink1073](https://github.com/blink1073))
- Bump actions/checkout from 2 to 3 [#58](https://github.com/jupyter-server/synchronizer/pull/58) ([@dependabot](https://github.com/dependabot))
- Add dependabot [#57](https://github.com/jupyter-server/synchronizer/pull/57) ([@blink1073](https://github.com/blink1073))
- Maintenance cleanup [#53](https://github.com/jupyter-server/synchronizer/pull/53) ([@blink1073](https://github.com/blink1073))
- Maintenance Cleanup [#52](https://github.com/jupyter-server/synchronizer/pull/52) ([@blink1073](https://github.com/blink1073))

### Documentation improvements

- Update the tagline for this extension to clarify that it rehydrates kernel sessions. [#71](https://github.com/jupyter-server/synchronizer/pull/71) ([@Zsailer](https://github.com/Zsailer))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/synchronizer/graphs/contributors?from=2022-08-16&to=2024-03-13&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Ablink1073+updated%3A2022-08-16..2024-03-13&type=Issues) | [@codecov](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Acodecov+updated%3A2022-08-16..2024-03-13&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Acodecov-commenter+updated%3A2022-08-16..2024-03-13&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Adependabot+updated%3A2022-08-16..2024-03-13&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Apre-commit-ci+updated%3A2022-08-16..2024-03-13&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3AZsailer+updated%3A2022-08-16..2024-03-13&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.0.9

([Full Changelog](https://github.com/jupyter-server/synchronizer/compare/v0.0.8...86ecf434d69d033f2682f5db4761f76938a9d7ca))

### Bugs fixed

- rm the redundant argument for list_sessions() [#42](https://github.com/jupyter-server/synchronizer/pull/42) ([@chiawchen](https://github.com/chiawchen))

### Maintenance and upkeep improvements

- \[pre-commit.ci\] pre-commit autoupdate [#40](https://github.com/jupyter-server/synchronizer/pull/40) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#39](https://github.com/jupyter-server/synchronizer/pull/39) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#38](https://github.com/jupyter-server/synchronizer/pull/38) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#37](https://github.com/jupyter-server/synchronizer/pull/37) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Do not use dev version yet [#36](https://github.com/jupyter-server/synchronizer/pull/36) ([@blink1073](https://github.com/blink1073))
- \[pre-commit.ci\] pre-commit autoupdate [#35](https://github.com/jupyter-server/synchronizer/pull/35) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#34](https://github.com/jupyter-server/synchronizer/pull/34) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#33](https://github.com/jupyter-server/synchronizer/pull/33) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#32](https://github.com/jupyter-server/synchronizer/pull/32) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#31](https://github.com/jupyter-server/synchronizer/pull/31) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#30](https://github.com/jupyter-server/synchronizer/pull/30) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Use hatch backend [#29](https://github.com/jupyter-server/synchronizer/pull/29) ([@blink1073](https://github.com/blink1073))
- \[pre-commit.ci\] pre-commit autoupdate [#28](https://github.com/jupyter-server/synchronizer/pull/28) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/synchronizer/graphs/contributors?from=2022-05-10&to=2022-08-16&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Ablink1073+updated%3A2022-05-10..2022-08-16&type=Issues) | [@chiawchen](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Achiawchen+updated%3A2022-05-10..2022-08-16&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Acodecov-commenter+updated%3A2022-05-10..2022-08-16&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Apre-commit-ci+updated%3A2022-05-10..2022-08-16&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Awelcome+updated%3A2022-05-10..2022-08-16&type=Issues)

## 0.0.8

([Full Changelog](https://github.com/jupyter-server/synchronizer/compare/v0.0.7...16a1a8788d92de699b7d00945ad07aaf421bfdd0))

### Bugs fixed

- Add missing list_sessions method [#26](https://github.com/jupyter-server/synchronizer/pull/26) ([@Zsailer](https://github.com/Zsailer))

### Maintenance and upkeep improvements

- \[pre-commit.ci\] pre-commit autoupdate [#25](https://github.com/jupyter-server/synchronizer/pull/25) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/synchronizer/graphs/contributors?from=2022-05-06&to=2022-05-10&type=c))

[@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Apre-commit-ci+updated%3A2022-05-06..2022-05-10&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3AZsailer+updated%3A2022-05-06..2022-05-10&type=Issues)

## 0.0.7

([Full Changelog](https://github.com/jupyter-server/synchronizer/compare/v0.0.6...720b7df76570a89d6391d4c103072f748cda1c47))

### Bugs fixed

- If synchronizer fails, warn gracefully and continue [#22](https://github.com/jupyter-server/synchronizer/pull/22) ([@Zsailer](https://github.com/Zsailer))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/synchronizer/graphs/contributors?from=2022-05-05&to=2022-05-06&type=c))

[@Zsailer](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3AZsailer+updated%3A2022-05-05..2022-05-06&type=Issues)

## 0.0.6

([Full Changelog](https://github.com/jupyter-server/synchronizer/compare/v0.0.5...11f5c8daa9501f39898a9a608014566db5075e44))

### Bugs fixed

- write only the allowed columns to the database [#19](https://github.com/jupyter-server/synchronizer/pull/19) ([@Zsailer](https://github.com/Zsailer))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/synchronizer/graphs/contributors?from=2022-05-05&to=2022-05-05&type=c))

[@Zsailer](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3AZsailer+updated%3A2022-05-05..2022-05-05&type=Issues)

## 0.0.5

([Full Changelog](https://github.com/jupyter-server/synchronizer/compare/v0.0.4...fbf531a2ffc46d200c2f037fa802438110027dd0))

### Bugs fixed

- Add relevant kernel name to persistent kernel storage for rehydration [#17](https://github.com/jupyter-server/synchronizer/pull/17) ([@Zsailer](https://github.com/Zsailer))

### Maintenance and upkeep improvements

- Use flit build backend [#16](https://github.com/jupyter-server/synchronizer/pull/16) ([@blink1073](https://github.com/blink1073))
- \[pre-commit.ci\] pre-commit autoupdate [#15](https://github.com/jupyter-server/synchronizer/pull/15) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/synchronizer/graphs/contributors?from=2022-04-29&to=2022-05-05&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Ablink1073+updated%3A2022-04-29..2022-05-05&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Apre-commit-ci+updated%3A2022-04-29..2022-05-05&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3AZsailer+updated%3A2022-04-29..2022-05-05&type=Issues)

## 0.0.4

([Full Changelog](https://github.com/jupyter-server/synchronizer/compare/v0.0.3...ca069ec88ee718ff24d014132dc3de7e187af6ea))

### Enhancements made

- Synchronizer as a session manager [#13](https://github.com/jupyter-server/synchronizer/pull/13) ([@Zsailer](https://github.com/Zsailer))
- Synchronizing before the server starts should be configurable. [#11](https://github.com/jupyter-server/synchronizer/pull/11) ([@Zsailer](https://github.com/Zsailer))

### Maintenance and upkeep improvements

- \[pre-commit.ci\] pre-commit autoupdate [#10](https://github.com/jupyter-server/synchronizer/pull/10) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- \[pre-commit.ci\] pre-commit autoupdate [#9](https://github.com/jupyter-server/synchronizer/pull/9) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/synchronizer/graphs/contributors?from=2022-04-12&to=2022-04-29&type=c))

[@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Apre-commit-ci+updated%3A2022-04-12..2022-04-29&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3AZsailer+updated%3A2022-04-12..2022-04-29&type=Issues)

## 0.0.3

([Full Changelog](https://github.com/jupyter-server/synchronizer/compare/v0.0.2...af4c669a9b4a41845451fa93be546aa442c9d680))

### Enhancements made

- Make Synchronizer work with Jupyter Kernel Gateways out-of-the-box [#7](https://github.com/jupyter-server/synchronizer/pull/7) ([@Zsailer](https://github.com/Zsailer))

### Maintenance and upkeep improvements

- Add typing support [#6](https://github.com/jupyter-server/synchronizer/pull/6) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/synchronizer/graphs/contributors?from=2022-04-12&to=2022-04-12&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Ablink1073+updated%3A2022-04-12..2022-04-12&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Awelcome+updated%3A2022-04-12..2022-04-12&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3AZsailer+updated%3A2022-04-12..2022-04-12&type=Issues)

## 0.0.2

([Full Changelog](https://github.com/jupyter-server/synchronizer/compare/v0.0.1...d48b159af0572834188a15a2501f5f26bae9644a))

### Enhancements made

- Make "kernel fetching" configurable and client-driven [#4](https://github.com/jupyter-server/synchronizer/pull/4) ([@Zsailer](https://github.com/Zsailer))

### Maintenance and upkeep improvements

- \[pre-commit.ci\] pre-commit autoupdate [#3](https://github.com/jupyter-server/synchronizer/pull/3) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-server/synchronizer/graphs/contributors?from=2022-04-05&to=2022-04-11&type=c))

[@pre-commit-ci](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3Apre-commit-ci+updated%3A2022-04-05..2022-04-11&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter-server%2Fsynchronizer+involves%3AZsailer+updated%3A2022-04-05..2022-04-11&type=Issues)

## 0.0.1
